==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1stop.js <==
var namespacegko_1_1stop =
[
    [ "AbsoluteResidualNorm", "classgko_1_1stop_1_1AbsoluteResidualNorm.html", "classgko_1_1stop_1_1AbsoluteResidualNorm" ],
    [ "Combined", "classgko_1_1stop_1_1Combined.html", "classgko_1_1stop_1_1Combined" ],
    [ "Criterion", "classgko_1_1stop_1_1Criterion.html", "classgko_1_1stop_1_1Criterion" ],
    [ "CriterionArgs", "structgko_1_1stop_1_1CriterionArgs.html", null ],
    [ "ImplicitResidualNorm", "classgko_1_1stop_1_1ImplicitResidualNorm.html", "classgko_1_1stop_1_1ImplicitResidualNorm" ],
    [ "Iteration", "classgko_1_1stop_1_1Iteration.html", "classgko_1_1stop_1_1Iteration" ],
    [ "RelativeResidualNorm", "classgko_1_1stop_1_1RelativeResidualNorm.html", "classgko_1_1stop_1_1RelativeResidualNorm" ],
    [ "ResidualNorm", "classgko_1_1stop_1_1ResidualNorm.html", "classgko_1_1stop_1_1ResidualNorm" ],
    [ "ResidualNormBase", "classgko_1_1stop_1_1ResidualNormBase.html", null ],
    [ "ResidualNormReduction", "classgko_1_1stop_1_1ResidualNormReduction.html", "classgko_1_1stop_1_1ResidualNormReduction" ],
    [ "Time", "classgko_1_1stop_1_1Time.html", "classgko_1_1stop_1_1Time" ],
    [ "CriterionFactory", "namespacegko_1_1stop.html#a61839f234ddbaaf68db337e58e012499", null ],
    [ "EnableDefaultCriterionFactory", "namespacegko_1_1stop.html#ac0bd01442b3deaeabb92865af218ba05", null ],
    [ "mode", "group__stop.html#ga5fe97c4263e876f68b5d4a21f0e615b9", [
      [ "absolute", "group__stop.html#gga5fe97c4263e876f68b5d4a21f0e615b9adc4d53aa0d117d8b189b36d161af4e96", null ],
      [ "initial_resnorm", "group__stop.html#gga5fe97c4263e876f68b5d4a21f0e615b9a025c2f0549e6e20e68b08133ca402005", null ],
      [ "rhs_norm", "group__stop.html#gga5fe97c4263e876f68b5d4a21f0e615b9a58a8ef085e1be515f3da62157613f158", null ]
    ] ],
    [ "combine", "group__stop.html#ga934dd0c4603a3e815c767f7628163d7e", null ]
];

==> ginkgo-hpc-docs-1.11.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1stop.js <==
var namespacegko_1_1stop =
[
    [ "Combined", "classgko_1_1stop_1_1Combined.html", "classgko_1_1stop_1_1Combined" ],
    [ "Criterion", "classgko_1_1stop_1_1Criterion.html", "classgko_1_1stop_1_1Criterion" ],
    [ "CriterionArgs", "structgko_1_1stop_1_1CriterionArgs.html", null ],
    [ "Iteration", "classgko_1_1stop_1_1Iteration.html", "classgko_1_1stop_1_1Iteration" ],
    [ "ResidualNormBase", "classgko_1_1stop_1_1ResidualNormBase.html", null ],
    [ "ResidualNorm", "classgko_1_1stop_1_1ResidualNorm.html", "classgko_1_1stop_1_1ResidualNorm" ],
    [ "ImplicitResidualNorm", "classgko_1_1stop_1_1ImplicitResidualNorm.html", "classgko_1_1stop_1_1ImplicitResidualNorm" ],
    [ "ResidualNormReduction", "classgko_1_1stop_1_1ResidualNormReduction.html", "classgko_1_1stop_1_1ResidualNormReduction" ],
    [ "RelativeResidualNorm", "classgko_1_1stop_1_1RelativeResidualNorm.html", "classgko_1_1stop_1_1RelativeResidualNorm" ],
    [ "AbsoluteResidualNorm", "classgko_1_1stop_1_1AbsoluteResidualNorm.html", "classgko_1_1stop_1_1AbsoluteResidualNorm" ],
    [ "Time", "classgko_1_1stop_1_1Time.html", "classgko_1_1stop_1_1Time" ],
    [ "CriterionFactory", "namespacegko_1_1stop.html#a61839f234ddbaaf68db337e58e012499", null ],
    [ "EnableDefaultCriterionFactory", "namespacegko_1_1stop.html#ac0bd01442b3deaeabb92865af218ba05", null ],
    [ "mode", "group__stop.html#ga5fe97c4263e876f68b5d4a21f0e615b9", null ],
    [ "combine", "group__stop.html#ga934dd0c4603a3e815c767f7628163d7e", null ]
];
